@@ -176,7 +176,7 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 %
 %  there should only a single extension defined for object files but
 %  but multiple extensions can be defined for Logtalk and Prolog source
-%  files and for back-end specific temporary files
+%  files and for backend specific temporary files
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
@@ -193,14 +193,14 @@ setup_call_cleanup(Setup, Call, Cleanup) :-
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  back-end Prolog compiler features
+%  backend Prolog compiler features
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
 % '$lgt_prolog_feature'(?atom, ?atom)
 %
-% back-end Prolog compiler supported features (that are compatible with Logtalk)
+% backend Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, cx).
 '$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
