@@ -152,7 +152,7 @@
 %
 %  there should only a single extension defined for object files but
 %  but multiple extensions can be defined for Logtalk and Prolog source
-%  files and for back-end specific temporary files
+%  files and for backend specific temporary files
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
@@ -170,14 +170,14 @@
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  back-end Prolog compiler features
+%  backend Prolog compiler features
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
 % '$lgt_prolog_feature'(?atom, ?atom)
 %
-% back-end Prolog compiler supported features (that are compatible with Logtalk)
+% backend Prolog compiler supported features (that are compatible with Logtalk)
 
 '$lgt_prolog_feature'(prolog_dialect, ji).
 '$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
