@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Release build script
-##   Last updated on October 30, 2018
+##   Last updated on November 23, 2018
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -23,15 +23,9 @@
 #############################################################################
 
 
-if [ -z "$1" ]; then
-	git clone --depth=1 git://github.com/LogtalkDotOrg/logtalk3.git lgtclone
-	version=$(sed -e 's/-stable$//' < lgtclone/VERSION.txt)
-
-	mv lgtclone "logtalk-$version"
-else
-	version="$1"
-	git clone --depth=1 git://github.com/LogtalkDotOrg/logtalk3.git "logtalk-$version"
-fi
+git clone --depth=1 git://github.com/LogtalkDotOrg/logtalk3.git lgtclone
+version=$(sed -e 's/-stable$//' < lgtclone/VERSION.txt)
+mv lgtclone "logtalk-$version"
 
 directory=$(PWD)
 
@@ -48,6 +42,14 @@ tar zcvf "logtalk-$version.tgz" logtalk
 mv "logtalk-$version.tgz" ..
 cd ..
 
+cp -R "logtalk-$version/scripts/pack-experimental" "pack-experimental-$version"
+cp -R "logtalk-$version" "pack-experimental-$version/logtalk"
+mv "pack-experimental-$version/settings.lgt" "pack-experimental-$version/logtalk/logtalk-$version"
+cd "pack-experimental-$version" || exit 1
+tar zcvf "logtalk-experimental-$version.tgz" logtalk
+mv "logtalk-experimental-$version.tgz" ..
+cd ..
+
 "logtalk-$version"/manuals/sources/build_manuals.sh
 cp -R "logtalk-$version/manuals" "logtalk-manuals-$version"
 tar -czf "logtalk-manuals-$version.tgz" "logtalk-manuals-$version"
