@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk installation script
-##   Last updated on May 16, 2018
+##   Last updated on October 12, 2018
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -128,12 +128,13 @@ ln -sf ../share/logtalk/tools/lgtdoc/xml/lgt2pdf.sh lgt2pdf
 ln -sf ../share/logtalk/tools/lgtdoc/xml/lgt2html.sh lgt2html
 ln -sf ../share/logtalk/tools/lgtdoc/xml/lgt2xml.sh lgt2xml
 ln -sf ../share/logtalk/tools/lgtdoc/xml/lgt2md.sh lgt2md
+ln -sf ../share/logtalk/tools/lgtdoc/xml/lgt2rst.sh lgt2rst
 ln -sf ../share/logtalk/tools/lgtdoc/xml/lgt2txt.sh lgt2txt
 
 echo "Links to the \"logtalk_user_setup\", \"logtalk_backend_select\","
 echo "\"logtalk_version_select\", \"logtalk_tester\", \"logtalk_doclet\","
-echo "\"lgt2pdf\", \"lgt2html\", \"lgt2xml\", \"lgt2md\", and \"lgt2txt\""
-echo "scripts have been created on \"$prefix/bin\";"
+echo "\"lgt2pdf\", \"lgt2html\", \"lgt2xml\", \"lgt2md\", \"lgt2rst\" and"
+echo "\"lgt2txt\" scripts have been created on \"$prefix/bin\";"
 echo "ensure that this directory is in your execution path."
 echo
 
@@ -159,7 +160,7 @@ for file in ../../logtalk/man/man1/*.1.gz ; do
 done
 
 echo "The following integration scripts are installed for running Logtalk"
-echo "with selected back-end Prolog compilers:"
+echo "with selected backend Prolog compilers:"
 echo
 echo "* B-Prolog (version 7.8 or later):         bplgt"
 echo "* CxProlog (version 0.98.1 or later):      cxlgt"
